diff --git a/core/modules/comment/src/Tests/CommentActionsTest.php b/core/modules/comment/src/Tests/CommentActionsTest.php
index e5443c1..d81e6f8 100644
--- a/core/modules/comment/src/Tests/CommentActionsTest.php
+++ b/core/modules/comment/src/Tests/CommentActionsTest.php
@@ -32,7 +32,7 @@ class CommentActionsTest extends CommentTestBase {
    * Tests comment publish and unpublish actions.
    */
   function testCommentPublishUnpublishActions() {
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $comment_text = $this->randomMachineName();
     $subject = $this->randomMachineName();
     $comment = $this->postComment($this->node, $comment_text, $subject);
@@ -52,7 +52,7 @@ function testCommentPublishUnpublishActions() {
    * Tests the unpublish comment by keyword action.
    */
   function testCommentUnpublishByKeyword() {
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $keyword_1 = $this->randomMachineName();
     $keyword_2 = $this->randomMachineName();
     $action = entity_create('action', array(
diff --git a/core/modules/comment/src/Tests/CommentAdminTest.php b/core/modules/comment/src/Tests/CommentAdminTest.php
index 811dfde..3414ab6 100644
--- a/core/modules/comment/src/Tests/CommentAdminTest.php
+++ b/core/modules/comment/src/Tests/CommentAdminTest.php
@@ -23,7 +23,7 @@ function testApprovalAdminInterface() {
       'post comments' => TRUE,
       'skip comment approval' => FALSE,
     ));
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentAnonymous('0'); // Ensure that doesn't require contact info.
 
     // Test that the comments page loads correctly when there are no comments
@@ -39,7 +39,7 @@ function testApprovalAdminInterface() {
     $this->assertText(t('Your comment has been queued for review by site administrators and will be published after approval.'), 'Comment requires approval.');
 
     // Get unapproved comment id.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $anonymous_comment4 = $this->getUnapprovedComment($subject);
     $anonymous_comment4 = entity_create('comment', array(
       'cid' => $anonymous_comment4,
@@ -54,7 +54,7 @@ function testApprovalAdminInterface() {
     $this->assertFalse($this->commentExists($anonymous_comment4), 'Anonymous comment was not published.');
 
     // Approve comment.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->performCommentOperation($anonymous_comment4, 'publish', TRUE);
     $this->drupalLogout();
 
@@ -66,7 +66,7 @@ function testApprovalAdminInterface() {
     $comments[] = $this->postComment($this->node, $this->randomMachineName(), $this->randomMachineName(), TRUE);
 
     // Publish multiple comments in one operation.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->drupalGet('admin/content/comment/approval');
     $this->assertText(t('Unapproved comments (@count)', array('@count' => 2)), 'Two unapproved comments waiting for approval.');
     $edit = array(
@@ -105,7 +105,7 @@ function testApprovalNodeInterface() {
       'post comments' => TRUE,
       'skip comment approval' => FALSE,
     ));
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentAnonymous('0'); // Ensure that doesn't require contact info.
     $this->drupalLogout();
 
@@ -116,7 +116,7 @@ function testApprovalNodeInterface() {
     $this->assertText(t('Your comment has been queued for review by site administrators and will be published after approval.'), 'Comment requires approval.');
 
     // Get unapproved comment id.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $anonymous_comment4 = $this->getUnapprovedComment($subject);
     $anonymous_comment4 = entity_create('comment', array(
       'cid' => $anonymous_comment4,
@@ -131,7 +131,7 @@ function testApprovalNodeInterface() {
     $this->assertFalse($this->commentExists($anonymous_comment4), 'Anonymous comment was not published.');
 
     // Approve comment.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->drupalGet('comment/1/approve');
     $this->assertResponse(403, 'Forged comment approval was denied.');
     $this->drupalGet('comment/1/approve', array('query' => array('token' => 'forged')));
@@ -151,7 +151,7 @@ function testApprovalNodeInterface() {
    */
   public function testCommentAdmin() {
     // Login.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     // Browse to comment bundle overview.
     $this->drupalGet('admin/structure/comment');
     $this->assertResponse(200);
diff --git a/core/modules/comment/src/Tests/CommentAnonymousTest.php b/core/modules/comment/src/Tests/CommentAnonymousTest.php
index da4b453..19fc6fa 100644
--- a/core/modules/comment/src/Tests/CommentAnonymousTest.php
+++ b/core/modules/comment/src/Tests/CommentAnonymousTest.php
@@ -34,7 +34,7 @@ protected function setUp() {
    * Tests anonymous comment functionality.
    */
   function testAnonymous() {
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentAnonymous('0'); // Ensure that doesn't require contact info.
     $this->drupalLogout();
 
@@ -43,7 +43,7 @@ function testAnonymous() {
     $this->assertTrue($this->commentExists($anonymous_comment1), 'Anonymous comment without contact info found.');
 
     // Allow contact info.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentAnonymous('1');
 
     // Attempt to edit anonymous comment.
@@ -61,7 +61,7 @@ function testAnonymous() {
 
     // Ensure anonymous users cannot post in the name of registered users.
     $edit = array(
-      'name' => $this->admin_user->getUsername(),
+      'name' => $this->adminUser->getUsername(),
       'mail' => $this->randomMachineName() . '@example.com',
       'subject[0][value]' => $this->randomMachineName(),
       'comment_body[0][value]' => $this->randomMachineName(),
@@ -70,7 +70,7 @@ function testAnonymous() {
     $this->assertText(t('The name you used belongs to a registered user.'));
 
     // Require contact info.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentAnonymous('2');
     $this->drupalLogout();
 
@@ -90,7 +90,7 @@ function testAnonymous() {
     $this->assertTrue($this->commentExists($anonymous_comment3), 'Anonymous comment with contact info (required) found.');
 
     // Make sure the user data appears correctly when editing the comment.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->drupalGet('comment/' . $anonymous_comment3->id() . '/edit');
     $this->assertRaw($author_name, "The anonymous user's name is correct when editing the comment.");
     $this->assertRaw($author_mail, "The anonymous user's email address is correct when editing the comment.");
diff --git a/core/modules/comment/src/Tests/CommentBlockTest.php b/core/modules/comment/src/Tests/CommentBlockTest.php
index cdbb4b0..d93a220 100644
--- a/core/modules/comment/src/Tests/CommentBlockTest.php
+++ b/core/modules/comment/src/Tests/CommentBlockTest.php
@@ -25,7 +25,7 @@ class CommentBlockTest extends CommentTestBase {
   protected function setUp() {
     parent::setUp();
     // Update admin user to have the 'administer blocks' permission.
-    $this->admin_user = $this->drupalCreateUser(array(
+    $this->adminUser = $this->drupalCreateUser(array(
       'administer content types',
       'administer comments',
       'skip comment approval',
@@ -40,7 +40,7 @@ protected function setUp() {
    * Tests the recent comments block.
    */
   function testRecentCommentBlock() {
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $block = $this->drupalPlaceBlock('views_block:comments_recent-block_1');
 
     // Add some test comments, with and without subjects. Because the 10 newest
@@ -64,7 +64,7 @@ function testRecentCommentBlock() {
 
     // Test that a user with the 'access comments' permission can see the
     // block.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $this->drupalGet('');
     $this->assertText(t('Recent comments'));
 
diff --git a/core/modules/comment/src/Tests/CommentCSSTest.php b/core/modules/comment/src/Tests/CommentCSSTest.php
index 770502b..f620551 100644
--- a/core/modules/comment/src/Tests/CommentCSSTest.php
+++ b/core/modules/comment/src/Tests/CommentCSSTest.php
@@ -33,8 +33,8 @@ protected function setUp() {
   function testCommentClasses() {
     // Create all permutations for comments, users, and nodes.
     $parameters = array(
-      'node_uid' => array(0, $this->web_user->id()),
-      'comment_uid' => array(0, $this->web_user->id(), $this->admin_user->id()),
+      'node_uid' => array(0, $this->webUser->id()),
+      'comment_uid' => array(0, $this->webUser->id(), $this->adminUser->id()),
       'comment_status' => array(CommentInterface::PUBLISHED, CommentInterface::NOT_PUBLISHED),
       'user' => array('anonymous', 'authenticated', 'admin'),
     );
@@ -68,13 +68,13 @@ function testCommentClasses() {
           break;
 
         case 'authenticated':
-          $this->drupalLogin($this->web_user);
-          $case['user_uid'] = $this->web_user->id();
+          $this->drupalLogin($this->webUser);
+          $case['user_uid'] = $this->webUser->id();
           break;
 
         case 'admin':
-          $this->drupalLogin($this->admin_user);
-          $case['user_uid'] = $this->admin_user->id();
+          $this->drupalLogin($this->adminUser);
+          $case['user_uid'] = $this->adminUser->id();
           break;
       }
       // Request the node with the comment.
diff --git a/core/modules/comment/src/Tests/CommentFieldsTest.php b/core/modules/comment/src/Tests/CommentFieldsTest.php
index 4f3edea..1ded5d1 100644
--- a/core/modules/comment/src/Tests/CommentFieldsTest.php
+++ b/core/modules/comment/src/Tests/CommentFieldsTest.php
@@ -80,7 +80,7 @@ public function testCommentFieldDelete() {
       'type' => 'test_node_type',
     ));
 
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
 
     $this->drupalGet('node/' . $node->nid->value);
     $elements = $this->cssSelect('.field-type-comment');
@@ -98,8 +98,8 @@ public function testCommentFieldDelete() {
    */
   function testCommentInstallAfterContentModule() {
     // Create a user to do module administration.
-    $this->admin_user = $this->drupalCreateUser(array('access administration pages', 'administer modules'));
-    $this->drupalLogin($this->admin_user);
+    $this->adminUser = $this->drupalCreateUser(array('access administration pages', 'administer modules'));
+    $this->drupalLogin($this->adminUser);
 
     // Drop default comment field added in CommentTestBase::setup().
     FieldStorageConfig::loadByName('node', 'comment')->delete();
@@ -140,8 +140,8 @@ function testCommentInstallAfterContentModule() {
     // Try to post a comment on each node. A failure will be triggered if the
     // comment body is missing on one of these forms, due to postComment()
     // asserting that the body is actually posted correctly.
-    $this->web_user = $this->drupalCreateUser(array('access content', 'access comments', 'post comments', 'skip comment approval'));
-    $this->drupalLogin($this->web_user);
+    $this->webUser = $this->drupalCreateUser(array('access content', 'access comments', 'post comments', 'skip comment approval'));
+    $this->drupalLogin($this->webUser);
     $this->postComment($book_node, $this->randomMachineName(), $this->randomMachineName());
   }
 
diff --git a/core/modules/comment/src/Tests/CommentInterfaceTest.php b/core/modules/comment/src/Tests/CommentInterfaceTest.php
index b174492..98eee30 100644
--- a/core/modules/comment/src/Tests/CommentInterfaceTest.php
+++ b/core/modules/comment/src/Tests/CommentInterfaceTest.php
@@ -23,7 +23,7 @@ class CommentInterfaceTest extends CommentTestBase {
    */
   function testCommentInterface() {
     // Set comments to have subject and preview disabled.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentPreview(DRUPAL_DISABLED);
     $this->setCommentForm(TRUE);
     $this->setCommentSubject(FALSE);
@@ -31,20 +31,20 @@ function testCommentInterface() {
     $this->drupalLogout();
 
     // Post comment #1 without subject or preview.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $comment_text = $this->randomMachineName();
     $comment = $this->postComment($this->node, $comment_text);
     $this->assertTrue($this->commentExists($comment), 'Comment found.');
 
     // Set comments to have subject and preview to required.
     $this->drupalLogout();
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentSubject(TRUE);
     $this->setCommentPreview(DRUPAL_REQUIRED);
     $this->drupalLogout();
 
     // Create comment #2 that allows subject and requires preview.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $subject_text = $this->randomMachineName();
     $comment_text = $this->randomMachineName();
     $comment = $this->postComment($this->node, $comment_text, $subject_text, TRUE);
@@ -58,14 +58,14 @@ function testCommentInterface() {
     $anonymous_comment->delete();
 
     // Check comment display.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $this->drupalGet('node/' . $this->node->id());
     $this->assertText($subject_text, 'Individual comment subject found.');
     $this->assertText($comment_text, 'Individual comment body found.');
 
     // Set comments to have subject and preview to optional.
     $this->drupalLogout();
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentSubject(TRUE);
     $this->setCommentPreview(DRUPAL_OPTIONAL);
 
@@ -87,14 +87,14 @@ function testCommentInterface() {
 
     // Test changing the comment author to a verified user.
     $this->drupalGet('comment/' . $comment->id() . '/edit');
-    $comment = $this->postComment(NULL, $comment->comment_body->value, $comment->getSubject(), array('name' => $this->web_user->getUsername()));
-    $this->assertTrue($comment->getAuthorName() == $this->web_user->getUsername() && $comment->getOwnerId() == $this->web_user->id(), 'Comment author successfully changed to a registered user.');
+    $comment = $this->postComment(NULL, $comment->comment_body->value, $comment->getSubject(), array('name' => $this->webUser->getUsername()));
+    $this->assertTrue($comment->getAuthorName() == $this->webUser->getUsername() && $comment->getOwnerId() == $this->webUser->id(), 'Comment author successfully changed to a registered user.');
 
     $this->drupalLogout();
 
     // Reply to comment #2 creating comment #3 with optional preview and no
     // subject though field enabled.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     // Deliberately use the wrong url to test
     // \Drupal\comment\Controller\CommentController::redirectNode().
     $this->drupalGet('comment/' . $this->node->id() . '/reply');
@@ -172,7 +172,7 @@ function testCommentInterface() {
 
     // Delete comment and make sure that reply is also removed.
     $this->drupalLogout();
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->deleteComment($comment);
     $this->deleteComment($comment_new_page);
 
@@ -181,19 +181,19 @@ function testCommentInterface() {
     $this->assertFalse($this->commentExists($reply, TRUE), 'Reply not found.');
 
     // Enabled comment form on node page.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentForm(TRUE);
     $this->drupalLogout();
 
     // Submit comment through node form.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $this->drupalGet('node/' . $this->node->id());
     $form_comment = $this->postComment(NULL, $this->randomMachineName(), $this->randomMachineName(), TRUE);
     $this->assertTrue($this->commentExists($form_comment), 'Form comment found.');
 
     // Disable comment form on node page.
     $this->drupalLogout();
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentForm(FALSE);
   }
 }
diff --git a/core/modules/comment/src/Tests/CommentLinksAlterTest.php b/core/modules/comment/src/Tests/CommentLinksAlterTest.php
index 4861aae..3ad1895 100644
--- a/core/modules/comment/src/Tests/CommentLinksAlterTest.php
+++ b/core/modules/comment/src/Tests/CommentLinksAlterTest.php
@@ -27,7 +27,7 @@ protected function setUp() {
    * Tests comment links altering.
    */
   public function testCommentLinksAlter() {
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $comment_text = $this->randomMachineName();
     $subject = $this->randomMachineName();
     $comment = $this->postComment($this->node, $comment_text, $subject);
diff --git a/core/modules/comment/src/Tests/CommentNewIndicatorTest.php b/core/modules/comment/src/Tests/CommentNewIndicatorTest.php
index d057415..6714a8e 100644
--- a/core/modules/comment/src/Tests/CommentNewIndicatorTest.php
+++ b/core/modules/comment/src/Tests/CommentNewIndicatorTest.php
@@ -71,7 +71,7 @@ protected function renderNewCommentsNodeLinks(array $node_ids) {
   public function testCommentNewCommentsIndicator() {
     // Test if the right links are displayed when no comment is present for the
     // node.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->drupalGet('node');
     $this->assertNoLink(t('@count comments', array('@count' => 0)));
     $this->assertLink(t('Read more'));
@@ -101,7 +101,7 @@ public function testCommentNewCommentsIndicator() {
     $this->drupalLogout();
 
     // Log in with 'web user' and check comment links.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $this->drupalGet('node');
     // Verify the data-history-node-last-comment-timestamp attribute. Given its
     // value, the drupal.node-new-comments-link library would determine that the
diff --git a/core/modules/comment/src/Tests/CommentNodeAccessTest.php b/core/modules/comment/src/Tests/CommentNodeAccessTest.php
index b50baf3..175feba 100644
--- a/core/modules/comment/src/Tests/CommentNodeAccessTest.php
+++ b/core/modules/comment/src/Tests/CommentNodeAccessTest.php
@@ -32,7 +32,7 @@ protected function setUp() {
     node_access_rebuild();
 
     // Re-create user.
-    $this->web_user = $this->drupalCreateUser(array(
+    $this->webUser = $this->drupalCreateUser(array(
       'access comments',
       'post comments',
       'create article content',
@@ -42,7 +42,7 @@ protected function setUp() {
     ));
 
     // Set the author of the created node to the web_user uid.
-    $this->node->setOwnerId($this->web_user->id())->save();
+    $this->node->setOwnerId($this->webUser->id())->save();
   }
 
   /**
@@ -50,7 +50,7 @@ protected function setUp() {
    */
   function testThreadedCommentView() {
     // Set comments to have subject required and preview disabled.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentPreview(DRUPAL_DISABLED);
     $this->setCommentForm(TRUE);
     $this->setCommentSubject(TRUE);
@@ -58,7 +58,7 @@ function testThreadedCommentView() {
     $this->drupalLogout();
 
     // Post comment.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $comment_text = $this->randomMachineName();
     $comment_subject = $this->randomMachineName();
     $comment = $this->postComment($this->node, $comment_text, $comment_subject);
diff --git a/core/modules/comment/src/Tests/CommentNodeChangesTest.php b/core/modules/comment/src/Tests/CommentNodeChangesTest.php
index 9da21d4..6ad0de4 100644
--- a/core/modules/comment/src/Tests/CommentNodeChangesTest.php
+++ b/core/modules/comment/src/Tests/CommentNodeChangesTest.php
@@ -21,7 +21,7 @@ class CommentNodeChangesTest extends CommentTestBase {
    * Tests that comments are deleted with the node.
    */
   function testNodeDeletion() {
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $comment = $this->postComment($this->node, $this->randomMachineName(), $this->randomMachineName());
     $this->assertTrue($comment->id(), 'The comment could be loaded.');
     $this->node->delete();
diff --git a/core/modules/comment/src/Tests/CommentNonNodeTest.php b/core/modules/comment/src/Tests/CommentNonNodeTest.php
index ccaa163..79a506c 100644
--- a/core/modules/comment/src/Tests/CommentNonNodeTest.php
+++ b/core/modules/comment/src/Tests/CommentNonNodeTest.php
@@ -31,7 +31,7 @@ class CommentNonNodeTest extends WebTestBase {
    *
    * @var \Drupal\user\UserInterface
    */
-  protected $admin_user;
+  protected $adminUser;
 
   protected function setUp() {
     parent::setUp();
@@ -52,7 +52,7 @@ protected function setUp() {
     $this->assertEqual($bundles['comment']['label'], 'Comment settings');
 
     // Create test user.
-    $this->admin_user = $this->drupalCreateUser(array(
+    $this->adminUser = $this->drupalCreateUser(array(
       'administer comments',
       'skip comment approval',
       'post comments',
@@ -247,7 +247,7 @@ function testCommentFunctionality() {
     $this->drupalGet('entity_test/structure/entity_test/entity-test/fields/entity_test.entity_test.comment');
     $this->assertNoField('edit-default-value-input-comment-und-0-status-0');
 
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
 
     // Post a comment.
     $comment1 = $this->postComment($this->entity, $this->randomMachineName(), $this->randomMachineName());
diff --git a/core/modules/comment/src/Tests/CommentPagerTest.php b/core/modules/comment/src/Tests/CommentPagerTest.php
index c3fa58e..18bb32d 100644
--- a/core/modules/comment/src/Tests/CommentPagerTest.php
+++ b/core/modules/comment/src/Tests/CommentPagerTest.php
@@ -21,7 +21,7 @@ class CommentPagerTest extends CommentTestBase {
    * Confirms comment paging works correctly with flat and threaded comments.
    */
   function testCommentPaging() {
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
 
     // Set comment variables.
     $this->setCommentForm(TRUE);
@@ -93,7 +93,7 @@ function testCommentPaging() {
    * Tests comment ordering and threading.
    */
   function testCommentOrderingThreading() {
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
 
     // Set comment variables.
     $this->setCommentForm(TRUE);
@@ -192,7 +192,7 @@ function assertCommentOrder(array $comments, array $expected_order) {
    * Tests calculation of first page with new comment.
    */
   function testCommentNewPageIndicator() {
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
 
     // Set comment variables.
     $this->setCommentForm(TRUE);
@@ -301,10 +301,10 @@ function testTwoPagers() {
     $this->drupalPostForm(NULL, array('fields[comment][settings_edit_form][settings][pager_id]' => 0), t('Save'));
     $this->assertNoText(t('Pager ID: @id', array('@id' => 0)), 'No summary for standard pager');
 
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
 
     // Add a new node with both comment fields open.
-    $node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->web_user->id()));
+    $node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->webUser->id()));
     // Set comment options.
     $comments = array();
     foreach (array('comment', 'comment_2') as $field_name) {
diff --git a/core/modules/comment/src/Tests/CommentPreviewTest.php b/core/modules/comment/src/Tests/CommentPreviewTest.php
index 8d188c3..23620a5 100644
--- a/core/modules/comment/src/Tests/CommentPreviewTest.php
+++ b/core/modules/comment/src/Tests/CommentPreviewTest.php
@@ -32,7 +32,7 @@ class CommentPreviewTest extends CommentTestBase {
    */
   function testCommentPreview() {
     // As admin user, configure comment settings.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentPreview(DRUPAL_OPTIONAL);
     $this->setCommentForm(TRUE);
     $this->setCommentSubject(TRUE);
@@ -40,13 +40,13 @@ function testCommentPreview() {
     $this->drupalLogout();
 
     // Login as web user and add a signature and a user picture.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     \Drupal::config('user.settings')->set('signatures', 1)->save();
     $test_signature = $this->randomMachineName();
     $edit['signature[value]'] = '<a href="http://example.com/">' . $test_signature. '</a>';
     $image = current($this->drupalGetTestFiles('image'));
     $edit['files[user_picture_0]'] = drupal_realpath($image->uri);
-    $this->drupalPostForm('user/' . $this->web_user->id() . '/edit', $edit, t('Save'));
+    $this->drupalPostForm('user/' . $this->webUser->id() . '/edit', $edit, t('Save'));
 
     // As the web user, fill in the comment form and preview the comment.
     $edit = array();
@@ -75,7 +75,7 @@ function testCommentPreview() {
    */
   function testCommentEditPreviewSave() {
     $web_user = $this->drupalCreateUser(array('access comments', 'post comments', 'skip comment approval',  'edit own comments'));
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentPreview(DRUPAL_OPTIONAL);
     $this->setCommentForm(TRUE);
     $this->setCommentSubject(TRUE);
diff --git a/core/modules/comment/src/Tests/CommentRssTest.php b/core/modules/comment/src/Tests/CommentRssTest.php
index 15ee9f4..ca3acda 100644
--- a/core/modules/comment/src/Tests/CommentRssTest.php
+++ b/core/modules/comment/src/Tests/CommentRssTest.php
@@ -28,7 +28,7 @@ class CommentRssTest extends CommentTestBase {
    */
   function testCommentRss() {
     // Find comment in RSS feed.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $this->postComment($this->node, $this->randomMachineName(), $this->randomMachineName());
     $this->drupalGet('rss.xml');
     $raw = '<comments>' . $this->node->url('canonical', array('fragment' => 'comments', 'absolute' => TRUE)) . '</comments>';
diff --git a/core/modules/comment/src/Tests/CommentStatisticsTest.php b/core/modules/comment/src/Tests/CommentStatisticsTest.php
index ea93f94..a3561ab 100644
--- a/core/modules/comment/src/Tests/CommentStatisticsTest.php
+++ b/core/modules/comment/src/Tests/CommentStatisticsTest.php
@@ -16,12 +16,18 @@
  * @group comment
  */
 class CommentStatisticsTest extends CommentTestBase {
+  /**
+   * A secondary user for posting comments.
+   *
+   * @var \Drupal\user\UserInterface
+   */
+  protected $webUser2;
 
   protected function setUp() {
     parent::setUp();
 
     // Create a second user to post comments.
-    $this->web_user2 = $this->drupalCreateUser(array(
+    $this->webUser2 = $this->drupalCreateUser(array(
       'post comments',
       'create article content',
       'edit own comments',
@@ -38,7 +44,7 @@ protected function setUp() {
   function testCommentNodeCommentStatistics() {
     $node_storage = $this->container->get('entity.manager')->getStorage('node');
     // Set comments to have subject and preview disabled.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentPreview(DRUPAL_DISABLED);
     $this->setCommentForm(TRUE);
     $this->setCommentSubject(FALSE);
@@ -49,11 +55,11 @@ function testCommentNodeCommentStatistics() {
     $node = $node_storage->load($this->node->id());
     $this->assertEqual($node->get('comment')->last_comment_timestamp, $this->node->getCreatedTime(), 'The initial value of node last_comment_timestamp is the node created date.');
     $this->assertEqual($node->get('comment')->last_comment_name, NULL, 'The initial value of node last_comment_name is NULL.');
-    $this->assertEqual($node->get('comment')->last_comment_uid, $this->web_user->id(), 'The initial value of node last_comment_uid is the node uid.');
+    $this->assertEqual($node->get('comment')->last_comment_uid, $this->webUser->id(), 'The initial value of node last_comment_uid is the node uid.');
     $this->assertEqual($node->get('comment')->comment_count, 0, 'The initial value of node comment_count is zero.');
 
     // Post comment #1 as web_user2.
-    $this->drupalLogin($this->web_user2);
+    $this->drupalLogin($this->webUser2);
     $comment_text = $this->randomMachineName();
     $this->postComment($this->node, $comment_text);
 
@@ -62,11 +68,11 @@ function testCommentNodeCommentStatistics() {
     $node_storage->resetCache(array($this->node->id()));
     $node = $node_storage->load($this->node->id());
     $this->assertEqual($node->get('comment')->last_comment_name, NULL, 'The value of node last_comment_name is NULL.');
-    $this->assertEqual($node->get('comment')->last_comment_uid, $this->web_user2->id(), 'The value of node last_comment_uid is the comment #1 uid.');
+    $this->assertEqual($node->get('comment')->last_comment_uid, $this->webUser2->id(), 'The value of node last_comment_uid is the comment #1 uid.');
     $this->assertEqual($node->get('comment')->comment_count, 1, 'The value of node comment_count is 1.');
 
     // Prepare for anonymous comment submission (comment approval enabled).
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     user_role_change_permissions(DRUPAL_ANONYMOUS_RID, array(
       'access comments' => TRUE,
       'post comments' => TRUE,
@@ -86,11 +92,11 @@ function testCommentNodeCommentStatistics() {
     $node_storage->resetCache(array($this->node->id()));
     $node = $node_storage->load($this->node->id());
     $this->assertEqual($node->get('comment')->last_comment_name, NULL, 'The value of node last_comment_name is still NULL.');
-    $this->assertEqual($node->get('comment')->last_comment_uid, $this->web_user2->id(), 'The value of node last_comment_uid is still the comment #1 uid.');
+    $this->assertEqual($node->get('comment')->last_comment_uid, $this->webUser2->id(), 'The value of node last_comment_uid is still the comment #1 uid.');
     $this->assertEqual($node->get('comment')->comment_count, 1, 'The value of node comment_count is still 1.');
 
     // Prepare for anonymous comment submission (no approval required).
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     user_role_change_permissions(DRUPAL_ANONYMOUS_RID, array(
       'access comments' => TRUE,
       'post comments' => TRUE,
diff --git a/core/modules/comment/src/Tests/CommentTestBase.php b/core/modules/comment/src/Tests/CommentTestBase.php
index 76083fe..46522e6 100644
--- a/core/modules/comment/src/Tests/CommentTestBase.php
+++ b/core/modules/comment/src/Tests/CommentTestBase.php
@@ -31,14 +31,14 @@
    *
    * @var \Drupal\user\UserInterface
    */
-  protected $admin_user;
+  protected $adminUser;
 
   /**
    * A normal user with permission to post comments.
    *
    * @var \Drupal\user\UserInterface
    */
-  protected $web_user;
+  protected $webUser;
 
   /**
    * A test node to which comments will be posted.
@@ -58,7 +58,7 @@ protected function setUp() {
     }
 
     // Create two test users.
-    $this->admin_user = $this->drupalCreateUser(array(
+    $this->adminUser = $this->drupalCreateUser(array(
       'administer content types',
       'administer comments',
       'administer comment types',
@@ -69,7 +69,7 @@ protected function setUp() {
       'access comments',
       'access content',
      ));
-    $this->web_user = $this->drupalCreateUser(array(
+    $this->webUser = $this->drupalCreateUser(array(
       'access comments',
       'post comments',
       'create article content',
@@ -82,7 +82,7 @@ protected function setUp() {
     $this->container->get('comment.manager')->addDefaultField('node', 'article');
 
     // Create a test node authored by the web user.
-    $this->node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->web_user->id()));
+    $this->node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->webUser->id()));
   }
 
   /**
diff --git a/core/modules/comment/src/Tests/CommentThreadingTest.php b/core/modules/comment/src/Tests/CommentThreadingTest.php
index 6fa1197..ab0d9b9 100644
--- a/core/modules/comment/src/Tests/CommentThreadingTest.php
+++ b/core/modules/comment/src/Tests/CommentThreadingTest.php
@@ -20,7 +20,7 @@ class CommentThreadingTest extends CommentTestBase {
    */
   function testCommentThreading() {
     // Set comments to have a subject with preview disabled.
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
     $this->setCommentPreview(DRUPAL_DISABLED);
     $this->setCommentForm(TRUE);
     $this->setCommentSubject(TRUE);
@@ -28,11 +28,11 @@ function testCommentThreading() {
     $this->drupalLogout();
 
     // Create a node.
-    $this->drupalLogin($this->web_user);
-    $this->node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->web_user->id()));
+    $this->drupalLogin($this->webUser);
+    $this->node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->webUser->id()));
 
     // Post comment #1.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $subject_text = $this->randomMachineName();
     $comment_text = $this->randomMachineName();
 
@@ -82,7 +82,7 @@ function testCommentThreading() {
     $this->assertParentLink($comment1_5->id(), $comment1->id());
 
     // Post comment #3 overall comment #5.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $subject_text = $this->randomMachineName();
     $comment_text = $this->randomMachineName();
 
diff --git a/core/modules/comment/src/Tests/CommentTitleTest.php b/core/modules/comment/src/Tests/CommentTitleTest.php
index 356ba1e..dd1c97a 100644
--- a/core/modules/comment/src/Tests/CommentTitleTest.php
+++ b/core/modules/comment/src/Tests/CommentTitleTest.php
@@ -27,8 +27,8 @@ public function testCommentEmptyTitles() {
     $this->setCommentSubject(TRUE);
 
     // Create a node.
-    $this->drupalLogin($this->web_user);
-    $this->node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->web_user->id()));
+    $this->drupalLogin($this->webUser);
+    $this->node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->webUser->id()));
 
     // Post comment #1 and verify that h3's are not rendered.
     $subject_text = $this->randomMachineName();
@@ -53,8 +53,8 @@ public function testCommentPopulatedTitles() {
     $this->setCommentSubject(TRUE);
 
     // Create a node.
-    $this->drupalLogin($this->web_user);
-    $this->node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->web_user->id()));
+    $this->drupalLogin($this->webUser);
+    $this->node = $this->drupalCreateNode(array('type' => 'article', 'promote' => 1, 'uid' => $this->webUser->id()));
 
     // Post comment #1 and verify that title is rendered in h3.
     $subject_text = $this->randomMachineName();
diff --git a/core/modules/comment/src/Tests/CommentTokenReplaceTest.php b/core/modules/comment/src/Tests/CommentTokenReplaceTest.php
index 2bf97f8..9ab585b 100644
--- a/core/modules/comment/src/Tests/CommentTokenReplaceTest.php
+++ b/core/modules/comment/src/Tests/CommentTokenReplaceTest.php
@@ -30,7 +30,7 @@ function testCommentTokenReplacement() {
       'language' => $language_interface,
     );
 
-    $this->drupalLogin($this->admin_user);
+    $this->drupalLogin($this->adminUser);
 
     // Set comment variables.
     $this->setCommentSubject(TRUE);
@@ -53,7 +53,7 @@ function testCommentTokenReplacement() {
     $tests['[comment:cid]'] = $comment->id();
     $tests['[comment:hostname]'] = String::checkPlain($comment->getHostname());
     $tests['[comment:author]'] = Xss::filter($comment->getAuthorName());
-    $tests['[comment:mail]'] = String::checkPlain($this->admin_user->getEmail());
+    $tests['[comment:mail]'] = String::checkPlain($this->adminUser->getEmail());
     $tests['[comment:homepage]'] = check_url($comment->getHomepage());
     $tests['[comment:title]'] = Xss::filter($comment->getSubject());
     $tests['[comment:body]'] = $comment->comment_body->processed;
@@ -68,7 +68,7 @@ function testCommentTokenReplacement() {
     $tests['[comment:entity:nid]'] = $comment->getCommentedEntityId();
     $tests['[comment:entity:title]'] = String::checkPlain($node->getTitle());
     $tests['[comment:author:uid]'] = $comment->getOwnerId();
-    $tests['[comment:author:name]'] = String::checkPlain($this->admin_user->getUsername());
+    $tests['[comment:author:name]'] = String::checkPlain($this->adminUser->getUsername());
 
     // Test to make sure that we generated something for each token.
     $this->assertFalse(in_array(0, array_map('strlen', $tests)), 'No empty tokens generated.');
@@ -81,13 +81,13 @@ function testCommentTokenReplacement() {
     // Generate and test unsanitized tokens.
     $tests['[comment:hostname]'] = $comment->getHostname();
     $tests['[comment:author]'] = $comment->getAuthorName();
-    $tests['[comment:mail]'] = $this->admin_user->getEmail();
+    $tests['[comment:mail]'] = $this->adminUser->getEmail();
     $tests['[comment:homepage]'] = $comment->getHomepage();
     $tests['[comment:title]'] = $comment->getSubject();
     $tests['[comment:body]'] = $comment->comment_body->value;
     $tests['[comment:parent:title]'] = $parent_comment->getSubject();
     $tests['[comment:entity]'] = $node->getTitle();
-    $tests['[comment:author:name]'] = $this->admin_user->getUsername();
+    $tests['[comment:author:name]'] = $this->adminUser->getUsername();
 
     foreach ($tests as $input => $expected) {
       $output = $token_service->replace($input, array('comment' => $comment), array('langcode' => $language_interface->getId(), 'sanitize' => FALSE));
diff --git a/core/modules/comment/src/Tests/CommentTranslationUITest.php b/core/modules/comment/src/Tests/CommentTranslationUITest.php
index 945e532..61bcbd9 100644
--- a/core/modules/comment/src/Tests/CommentTranslationUITest.php
+++ b/core/modules/comment/src/Tests/CommentTranslationUITest.php
@@ -24,7 +24,14 @@ class CommentTranslationUITest extends ContentTranslationUITest {
   protected $subject;
 
   /**
-   * Modules to install.
+   * An administrative user with permission to administer comments.
+   *
+   * @var \Drupal\user\UserInterface
+   */
+  protected $adminUser;
+
+  /**
+   * Modules to enable.
    *
    * @var array
    */
@@ -143,8 +150,8 @@ protected function assertPublishedStatus() {
    * Tests translate link on comment content admin page.
    */
   function testTranslateLinkCommentAdminPage() {
-    $this->admin_user = $this->drupalCreateUser(array_merge(parent::getTranslatorPermissions(), array('access administration pages', 'administer comments', 'skip comment approval')));
-    $this->drupalLogin($this->admin_user);
+    $this->adminUser = $this->drupalCreateUser(array_merge(parent::getTranslatorPermissions(), array('access administration pages', 'administer comments', 'skip comment approval')));
+    $this->drupalLogin($this->adminUser);
 
     $cid_translatable = $this->createEntity(array(), $this->langcodes[0]);
     $cid_untranslatable = $this->createEntity(array(), $this->langcodes[0], 'comment');
diff --git a/core/modules/comment/src/Tests/CommentTypeTest.php b/core/modules/comment/src/Tests/CommentTypeTest.php
index 8bad469..148d1ef 100644
--- a/core/modules/comment/src/Tests/CommentTypeTest.php
+++ b/core/modules/comment/src/Tests/CommentTypeTest.php
@@ -21,7 +21,7 @@
 class CommentTypeTest extends CommentTestBase {
 
   /**
-   * Admin user
+   * Admin user.
    *
    * @var \Drupal\Core\Session\AccountInterface
    */
diff --git a/core/modules/comment/src/Tests/Views/ArgumentUserUIDTest.php b/core/modules/comment/src/Tests/Views/ArgumentUserUIDTest.php
index 040c595..9b0ed7f 100644
--- a/core/modules/comment/src/Tests/Views/ArgumentUserUIDTest.php
+++ b/core/modules/comment/src/Tests/Views/ArgumentUserUIDTest.php
@@ -28,10 +28,10 @@ function testCommentUserUIDTest() {
     $this->executeView($view, array($this->account->id()));
     $result_set = array(
       array(
-        'nid' => $this->node_user_posted->id(),
+        'nid' => $this->nodeUserPosted->id(),
       ),
       array(
-        'nid' => $this->node_user_commented->id(),
+        'nid' => $this->nodeUserCommented->id(),
       ),
     );
     $column_map = array('nid' => 'nid');
diff --git a/core/modules/comment/src/Tests/Views/CommentFieldFilterTest.php b/core/modules/comment/src/Tests/Views/CommentFieldFilterTest.php
index e848ceb..a054288 100644
--- a/core/modules/comment/src/Tests/Views/CommentFieldFilterTest.php
+++ b/core/modules/comment/src/Tests/Views/CommentFieldFilterTest.php
@@ -34,7 +34,7 @@ class CommentFieldFilterTest extends CommentTestBase {
    *
    * @var array
    */
-  public $comment_titles = array();
+  public $commentTitles = array();
 
   function setUp() {
     parent::setUp();
@@ -51,7 +51,7 @@ function setUp() {
     $field_storage->save();
 
     // Set up comment titles.
-    $this->comment_titles = array(
+    $this->commentTitles = array(
       'en' => 'Food in Paris',
       'es' => 'Comida en Paris',
       'fr' => 'Nouriture en Paris',
@@ -61,7 +61,7 @@ function setUp() {
     // as it predates the language set-up.
     $comment = array(
       'uid' => $this->loggedInUser->id(),
-      'entity_id' => $this->node_user_commented->id(),
+      'entity_id' => $this->nodeUserCommented->id(),
       'entity_type' => 'node',
       'field_name' => 'comment',
       'cid' => '',
@@ -71,14 +71,14 @@ function setUp() {
     $this->comment = entity_create('comment', $comment);
 
     // Add field values and translate the comment.
-    $this->comment->subject->value = $this->comment_titles['en'];
-    $this->comment->comment_body->value = $this->comment_titles['en'];
+    $this->comment->subject->value = $this->commentTitles['en'];
+    $this->comment->comment_body->value = $this->commentTitles['en'];
     $this->comment->langcode = 'en';
     $this->comment->save();
     foreach (array('es', 'fr') as $langcode) {
       $translation = $this->comment->addTranslation($langcode, array());
-      $translation->comment_body->value = $this->comment_titles[$langcode];
-      $translation->subject->value = $this->comment_titles[$langcode];
+      $translation->comment_body->value = $this->commentTitles[$langcode];
+      $translation->subject->value = $this->commentTitles[$langcode];
     }
     $this->comment->save();
   }
@@ -124,7 +124,7 @@ protected function assertPageCounts($path, $counts, $message) {
     // page, and they are the same. So the title/body string should appear on
     // the page twice as many times as the input count.
     foreach ($counts as $langcode => $count) {
-      $this->assertEqual(substr_count($text, $this->comment_titles[$langcode]), 2 * $count, 'Translation ' . $langcode . ' has count ' . $count . ' with ' . $message);
+      $this->assertEqual(substr_count($text, $this->commentTitles[$langcode]), 2 * $count, 'Translation ' . $langcode . ' has count ' . $count . ' with ' . $message);
     }
   }
 }
diff --git a/core/modules/comment/src/Tests/Views/CommentTestBase.php b/core/modules/comment/src/Tests/Views/CommentTestBase.php
index 5b3b8ca..306ab24 100644
--- a/core/modules/comment/src/Tests/Views/CommentTestBase.php
+++ b/core/modules/comment/src/Tests/Views/CommentTestBase.php
@@ -23,11 +23,39 @@
   public static $modules = array('node', 'comment', 'comment_test_views');
 
   /**
+   * A normal user with permission to post comments (without approval).
+   *
+   * @var \Drupal\user\UserInterface
+   */
+  protected $account;
+
+  /**
+   * A second normal user that will author a node for $account to comment on.
+   *
+   * @var \Drupal\user\UserInterface
+   */
+  protected $account2;
+
+  /**
+   * Stores a node posted by the user created as $account.
+   *
+   * @var \Drupal\node\NodeInterface
+   */
+  protected $nodeUserPosted;
+
+  /**
+   * Stores a node posted by the user created as $account2.
+   *
+   * @var \Drupal\node\NodeInterface
+   */
+  protected $nodeUserCommented;
+
+  /**
    * Stores a comment used by the tests.
    *
    * @var \Drupal\comment\Entity\Comment
    */
-  public $comment;
+  protected $comment;
 
   protected function setUp() {
     parent::setUp();
@@ -43,12 +71,12 @@ protected function setUp() {
     $this->drupalCreateContentType(array('type' => 'page', 'name' => t('Basic page')));
     $this->container->get('comment.manager')->addDefaultField('node', 'page');
 
-    $this->node_user_posted = $this->drupalCreateNode();
-    $this->node_user_commented = $this->drupalCreateNode(array('uid' => $this->account2->id()));
+    $this->nodeUserPosted = $this->drupalCreateNode();
+    $this->nodeUserCommented = $this->drupalCreateNode(array('uid' => $this->account2->id()));
 
     $comment = array(
       'uid' => $this->loggedInUser->id(),
-      'entity_id' => $this->node_user_commented->id(),
+      'entity_id' => $this->nodeUserCommented->id(),
       'entity_type' => 'node',
       'field_name' => 'comment',
       'cid' => '',
diff --git a/core/modules/comment/src/Tests/Views/FilterUserUIDTest.php b/core/modules/comment/src/Tests/Views/FilterUserUIDTest.php
index 92e40c7..b2fe796 100644
--- a/core/modules/comment/src/Tests/Views/FilterUserUIDTest.php
+++ b/core/modules/comment/src/Tests/Views/FilterUserUIDTest.php
@@ -40,14 +40,14 @@ function testCommentUserUIDTest() {
     $this->executeView($view, array($this->account->id()));
     $result_set = array(
       array(
-        'nid' => $this->node_user_posted->id(),
+        'nid' => $this->nodeUserPosted->id(),
       ),
       array(
-        'nid' => $this->node_user_commented->id(),
+        'nid' => $this->nodeUserCommented->id(),
       ),
     );
-    $this->column_map = array('nid' => 'nid');
-    $this->assertIdenticalResultset($view, $result_set, $this->column_map);
+    $column_map = array('nid' => 'nid');
+    $this->assertIdenticalResultset($view, $result_set, $column_map);
   }
 
 }
diff --git a/core/modules/rdf/src/Tests/CommentAttributesTest.php b/core/modules/rdf/src/Tests/CommentAttributesTest.php
index d03cfb5..72ff72b 100644
--- a/core/modules/rdf/src/Tests/CommentAttributesTest.php
+++ b/core/modules/rdf/src/Tests/CommentAttributesTest.php
@@ -119,11 +119,11 @@ protected function setUp() {
    */
   public function testNumberOfCommentsRdfaMarkup() {
     // Posts 2 comments on behalf of registered user.
-    $this->saveComment($this->node->id(), $this->web_user->id());
-    $this->saveComment($this->node->id(), $this->web_user->id());
+    $this->saveComment($this->node->id(), $this->webUser->id());
+    $this->saveComment($this->node->id(), $this->webUser->id());
 
     // Tests number of comments in teaser view.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $parser = new \EasyRdf_Parser_Rdfa();
     $graph = new \EasyRdf_Graph();
     $parser->parse($graph, $this->drupalGet('node'), 'rdfa', $this->baseUri);
@@ -151,10 +151,10 @@ public function testNumberOfCommentsRdfaMarkup() {
    */
   public function testCommentRdfaMarkup() {
     // Posts comment #1 on behalf of registered user.
-    $comment1 = $this->saveComment($this->node->id(), $this->web_user->id());
+    $comment1 = $this->saveComment($this->node->id(), $this->webUser->id());
 
     // Tests comment #1 with access to the user profile.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $parser = new \EasyRdf_Parser_Rdfa();
     $graph = new \EasyRdf_Graph();
     $parser->parse($graph, $this->drupalGet('node/' . $this->node->id()), 'rdfa', $this->baseUri);
@@ -181,7 +181,7 @@ public function testCommentRdfaMarkup() {
     $this->_testBasicCommentRdfaMarkup($graph, $comment2, $anonymous_user);
 
     // Tests comment #2 as logged in user.
-    $this->drupalLogin($this->web_user);
+    $this->drupalLogin($this->webUser);
     $parser = new \EasyRdf_Parser_Rdfa();
     $graph = new \EasyRdf_Graph();
     $parser->parse($graph, $this->drupalGet('node/' . $this->node->id()), 'rdfa', $this->baseUri);
@@ -193,13 +193,13 @@ public function testCommentRdfaMarkup() {
    */
   public function testCommentReplyOfRdfaMarkup() {
     // Posts comment #1 on behalf of registered user.
-    $this->drupalLogin($this->web_user);
-    $comment_1 = $this->saveComment($this->node->id(), $this->web_user->id());
+    $this->drupalLogin($this->webUser);
+    $comment_1 = $this->saveComment($this->node->id(), $this->webUser->id());
 
     $comment_1_uri = $comment_1->url('canonical', ['absolute' => TRUE]);
 
     // Posts a reply to the first comment.
-    $comment_2 = $this->saveComment($this->node->id(), $this->web_user->id(), NULL, $comment_1->id());
+    $comment_2 = $this->saveComment($this->node->id(), $this->webUser->id(), NULL, $comment_1->id());
     $comment_2_uri = $comment_2->url('canonical', ['absolute' => TRUE]);
 
     $parser = new \EasyRdf_Parser_Rdfa();
@@ -305,7 +305,7 @@ function _testBasicCommentRdfaMarkup($graph, CommentInterface $comment, $account
     }
 
     // Author name.
-    $name = empty($account["name"]) ? $this->web_user->getUsername() : $account["name"] . " (not verified)";
+    $name = empty($account["name"]) ? $this->webUser->getUsername() : $account["name"] . " (not verified)";
     $expected_value = array(
       'type' => 'literal',
       'value' => $name,

diff --git a/core/modules/comment/src/Tests/CommentLinksTest.php b/core/modules/comment/src/Tests/CommentLinksTest.php
index 34b8b41..0fbfa77 100644
--- a/core/modules/comment/src/Tests/CommentLinksTest.php
+++ b/core/modules/comment/src/Tests/CommentLinksTest.php
@@ -52,9 +52,9 @@ public function testCommentLinks() {
       ->set('default', 'stark')
       ->save();
 
     // Remove additional user permissions from $this->web_user added by setUp(),
     // since this test is limited to anonymous and authenticated roles only.
-    $roles = $this->web_user->getRoles();
+    $roles = $this->webUser->getRoles();
     entity_delete_multiple('user_role', array(reset($roles)));
 
     // Create a comment via CRUD API functionality, since
@@ -52,9 +52,9 @@ public function testCommentLinks() {
       ->save();
 
-    // Remove additional user permissions from $this->web_user added by setUp(),
+    // Remove additional user permissions from $this->webUser added by setUp(),
     // since this test is limited to anonymous and authenticated roles only.